/**
 * Copyright 2007-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.pool.annotation;

import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_MAX;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_MAX_WAITERS;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_MIN;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_SPARE;
import static org.ow2.util.pool.api.IPoolConfiguration.DEFAULT_TIMEOUT;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * Allow to specify pool attributes.
 * @author Florent BENOIT
 */
@Target(TYPE)
@Retention(RUNTIME)
public @interface Pool {

    /**
     * Maximum size of the pool (default is unlimited).
     */
    int max() default DEFAULT_MAX;

    /**
     * Minimum size of the pool (default is 0).
     */
    int min() default DEFAULT_MIN;

    /**
     * Spare size of the pool (default is 15).
     */
    int spare() default DEFAULT_SPARE;

    /**
     * Timeout (default is 10s = 10000L).
     */
    long timeout() default DEFAULT_TIMEOUT;

    /**
     * Number of waiters that can wait if the pool has reached its maximum value (default is 1000).
     */
    int maxWaiters() default DEFAULT_MAX_WAITERS;
}
