/**
 * Copyright 2007-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.pool.api;

/**
 * Defines the attributes that can be set on the pool in order to configure it.
 * @author Florent BENOIT
 */
public interface IPoolConfiguration {

    /**
     * Default min is 0.
     */
    int DEFAULT_MIN = 0;

    /**
     * Default max is unlimited.
     */
    int DEFAULT_MAX = -1;

    /**
     * Default spare is 15.
     */
    int DEFAULT_SPARE = 15;

    /**
     * Default timeout = 10 second.
     */
    long DEFAULT_TIMEOUT = 10000L;

    /**
     * Default max waiters = 1000.
     */
    int DEFAULT_MAX_WAITERS = 1000;

    /**
     * @return Minimum size of the pool.
     */
    int getMin();

    /**
     * Sets the Minimum size of the pool.
     * @param min the given minimum size of the pool
     */
    void setMin(final int min);

    /**
     * @return the spare size of instance of the pool.
     */
    int getSpare();

    /**
     * Sets the spare size of instance of the pool.
     * @param spare the spare size of instance of the pool.
     */
    void setSpare(final int spare);

    /**
     * @return Maximum size of the pool.
     */
    int getMax();

    /**
     * Sets the Maximum size of the pool.
     * @param max the given maximum size of the pool
     */
    void setMax(final int max);

    /**
     * @return the timeout for waiters that are waiting for an empty element in the pool.
     */
    long getTimeout();

    /**
     * Sets the timeout for waiters that are waiting for an empty element in the pool..
     * @param timeout the timeout for waiters that are waiting for an empty element in the pool.
     */
    void setTimeout(final long timeout);

    /**
     * @return the number of waiters that can wait for the given timeout. If this number is
     * reached, there is no wait and an exception is thrown.
     */
    int getMaxWaiters();

    /**
     * Sets the number of waiters that can wait for the given timeout.
     * @param maxWaiters the number of waiters that can wait for the given timeout.
     */
    void setMaxWaiters(final int maxWaiters);


}
